/***
 * Juliac
 * Copyright (C) 2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.julia.control.lifecycle;

import org.objectweb.fractal.juliac.control.lifecycle.InvocationCounterItf;

/**
 * Extend the implementation of the lifecycle control component to take into
 * account the fact the lifecycle interceptor component invokes the {@link
 * #decrementFcInvocationCounter()} method in all cases.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public abstract class UltraCompBasicLifeCycleControllerMixin
implements InvocationCounterItf {

    // -------------------------------------------------------------------------
    // Fields and methods added and overriden by the mixin class
    // -------------------------------------------------------------------------

	public void decrementFcInvocationCounter() {
		if ( _this_fcState != 2 ) {
			_super_decrementFcInvocationCounter();
		}
		else {
			_this_fcInvocationCounter--;
		}
	}

    // -------------------------------------------------------------------------
    // Fields and methods required by the mixin class in the base class
    // -------------------------------------------------------------------------

    @SuppressWarnings("unused")
	private int _this_fcInvocationCounter;
	private int _this_fcState;
    protected abstract void _super_decrementFcInvocationCounter();
}
